==> murrine-0.13.tar.bz2: murrine-0.13/src/murrine_rc_style.h <==
/* Murrine theme engine
 * Copyright (C) 2005 Andrea Cimitan.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Written by Owen Taylor <otaylor@redhat.com>
 * and by Alexander Larsson <alexl@redhat.com>
 * Modified by Richard Stellingwerff <remenic@gmail.com>
 * Modified by Kulyk Nazar <schamane@myeburg.net>
 * Modified by Andrea Cimitan <andrea.cimitan@gmail.com>
 */

#include <gtk/gtkrc.h>

typedef struct _MurrineRcStyle MurrineRcStyle;
typedef struct _MurrineRcStyleClass MurrineRcStyleClass;

extern GType murrine_type_rc_style;

#define MURRINE_TYPE_RC_STYLE              murrine_type_rc_style
#define MURRINE_RC_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), MURRINE_TYPE_RC_STYLE, MurrineRcStyle))
#define MURRINE_RC_STYLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), MURRINE_TYPE_RC_STYLE, MurrineRcStyleClass))
#define MURRINE_IS_RC_STYLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), MURRINE_TYPE_RC_STYLE))
#define MURRINE_IS_RC_STYLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), MURRINE_TYPE_RC_STYLE))
#define MURRINE_RC_STYLE_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), MURRINE_TYPE_RC_STYLE, MurrineRcStyleClass))

struct _MurrineRcStyle
{
  GtkRcStyle parent_instance;

  GdkColor scrollbar_color;
  gboolean has_scrollbar_color;
  double contrast;
  guint8 glazestyle;
  guint8 progressbarstyle;
  guint8 menubarstyle;
  guint8 menubaritemstyle;
  guint8 menuitemstyle;
  guint8 listviewheaderstyle;
  guint8 scrollbarstyle;
  guint8 squaredstyle;
  gboolean animation;
};

struct _MurrineRcStyleClass
{
  GtkRcStyleClass parent_class;
};

void murrine_rc_style_register_type (GTypeModule *module);

==> murrine-0.40.1.tar.bz2: murrine-0.40.1/src/murrine_rc_style.h <==
/* Murrine theme engine
 * Copyright (C) 2005 Andrea Cimitan.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Written by Owen Taylor <otaylor@redhat.com>
 * and by Alexander Larsson <alexl@redhat.com>
 * Modified by Richard Stellingwerff <remenic@gmail.com>
 * Modified by Kulyk Nazar <schamane@myeburg.net>
 * Modified by Andrea Cimitan <andrea.cimitan@gmail.com>
 */

#include <gtk/gtkrc.h>

typedef struct _MurrineRcStyle MurrineRcStyle;
typedef struct _MurrineRcStyleClass MurrineRcStyleClass;

G_GNUC_INTERNAL extern GType murrine_type_rc_style;

#define MURRINE_TYPE_RC_STYLE              murrine_type_rc_style
#define MURRINE_RC_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), MURRINE_TYPE_RC_STYLE, MurrineRcStyle))
#define MURRINE_RC_STYLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), MURRINE_TYPE_RC_STYLE, MurrineRcStyleClass))
#define MURRINE_IS_RC_STYLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), MURRINE_TYPE_RC_STYLE))
#define MURRINE_IS_RC_STYLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), MURRINE_TYPE_RC_STYLE))
#define MURRINE_RC_STYLE_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), MURRINE_TYPE_RC_STYLE, MurrineRcStyleClass))

struct _MurrineRcStyle
{
  GtkRcStyle parent_instance;

  GdkColor scrollbar_color;
  gboolean has_scrollbar_color;
  double contrast;
  guint8 glazestyle;
  guint8 progressbarstyle;
  guint8 menubarstyle;
  guint8 menubaritemstyle;
  guint8 menuitemstyle;
  guint8 listviewheaderstyle;
  guint8 listviewstyle;
  guint8 scrollbarstyle;
  guint8 roundness;
  gboolean animation;
};

struct _MurrineRcStyleClass
{
  GtkRcStyleClass parent_class;
};

G_GNUC_INTERNAL void murrine_rc_style_register_type (GTypeModule *module);
